#!/bin/bash
# Store menu options selected by the user
INPUT=/tmp/menu.sh.$$
 
# Storage file
OUTPUT=/tmp/output.sh.$$
 
# trap and delete temp files
trap "rm $OUTPUT; rm $INPUT; exit" SIGHUP SIGINT SIGTERM
 
#
# Purpose - display output using msgbox 
#  $1 -> set msgbox height
#  $2 -> set msgbox width
#  $3 -> set msgbox title
#
function display_output(){
	local h=${1-10}			# box height default 10
	local w=${2-81} 		# box width default 81
	local t=${3-Output} 	# box title 
	dialog --backtitle "RK3XXX Image Modding Tool" --title "${t}" --clear --msgbox "$(<$OUTPUT)" ${h} ${w}
}
#
#
function unpack_img(){
	echo "Hit -enter- key to unpack rk3XXX.img." >$OUTPUT
    display_output 6 60 "Unpacking Image"
cd unpack
./rkunpack *.img
cd ..
}
#
# Purpose - Mount an android System.img file for modding
#
function mount_system(){
	echo "Hit -enter- key to mount system.img." >$OUTPUT
    display_output 6 60 "Mounting System.image - you must supply root password"
sudo mount -t ext4 ./unpack/Image/system.img ./system_mount -o loop
}
#
function mv_apps_keep(){
	echo "Hit -enter- key to move all the apps we are sure we want into a "keep" directory inside of "app" directory (makes cleaning up easier)" >$OUTPUT
    display_output 6 60 "Creating "keep" directory and moving apps we want to keep for sure"
sudo ./mvapps.sh
}
#
function open_root_file_explorer(){
	echo "Hit -enter- key to open a Nautilus as root for modifying mounted system.img" >$OUTPUT
    display_output 6 60 "Opening Nautilus in mounted system.img directory - you may need to supply root password"
cd system_mount
sudo nautilus .
cd ..
}
#
function add_apps(){
	echo "Hit -enter- key to add useful apps" >$OUTPUT
    display_output 6 60 "Will add: Flashplayer, ESFileExplorer, googlemusic, Gallery (with picasa support), shared object library for english keyboard, latinime (english keyboard), latinime dictionary, asus weather widget and news widget"
sudo ./addapps.sh
}
#
function mv_apps_back(){
	echo "Hit -enter- key to move all the apps in the "app/keep" directory back into the proper app directory. Only useful if you already used the "Move_Apps" option." >$OUTPUT
    display_output 6 60 "Moving apps out of "keep" directory into app directory and deleting "keep" dir."
sudo mv system_mount/app/keep/* system_mount/app/
sudo rmdir system_mount/app/keep/
}
#
function tnt_prop_mod(){
	echo "Hit -enter- key to write TNT/Samsung SIII/English values to build.prop (backs up build.prop first)" >$OUTPUT
    display_output 6 60 "Writing SIII/English Values to build.prop - you may need to supply root password"
sudo ./propmod.sh
}
#
function boot_animation(){
	echo "Hit -enter- to change to clean google nexus "X" boot animation" >$OUTPUT
    display_output 6 60 "This will change your rom's boot animation"
sudo cp -fap ref/media/bootanimation.zip system_mount/media/bootanimation.zip
}
#
function input_sounds(){
	echo "Hit -enter- to change keyboard keypress sounds to nicer CM based sounds" >$OUTPUT
    display_output 6 60 "This will change your rom's keyboard keypress sounds"
sudo mkdir system_mount/media/rkfactory
sudo rm -rf system_mount/media/rkfactory/*
sudo cp -fap ref/media/rkfactory/* system_mount/media/rkfactory
sudo cp -fap ref/media/audio/ui/* system_mount/media/audio/ui 
}
#
function clean_desktop(){
	echo "This will clean a stock rom of the default desktop application shortcuts. You want this if you removed a bunch of chinese apps. Also sets permissions for default_wallpaper.jpg (will not harm anything)" >$OUTPUT
    display_output 6 60 "Writing SIII/English Values to build.prop - you may need to supply root password"
sudo mkdir system_mount/usr/DATAOLD 
sudo mv system_mount/usr/data/* system_mount/usr/DATAOLD/
sudo chown system_mount/media/rkfactory/default_wallpaper.jpg --reference ref/media/rkfactory/default_wallpaper.jpg
sudo chmod system_mount/media/rkfactory/default_wallpaper.jpg --reference ref/media/rkfactory/default_wallpaper.jpg
}
#
function root(){
	echo "Hit -enter- to root your rom" >$OUTPUT
    display_output 6 60 "This will root your rom"
sudo ./root.sh
}
#
function unmount_system(){
	echo "Hit -enter- key to unmount system.img." >$OUTPUT
    display_output 6 60 "unmounting System.image - you may need to supply root password"
sudo umount system_mount
}
#
function package_rom_1(){
	echo "Hit -enter- key to do step 1 of packaging your rom" >$OUTPUT
    display_output 6 60 "packaging your rom..."
./tools/afptool -pack ./unpack/ ./temp.img
}
#
function package_rom_2_3066(){
	echo "Hit -enter- key to do the final step of packaging your RK3066 rom" >$OUTPUT
    display_output 6 60 "packaging your RK3066 rom..."
cd unpack
BIN="$( echo *.bin | head -1 | tail -1 )"
cd ..
./tools/img_maker_rk3066 ./unpack/"$BIN" ./temp.img ./final_rk3066.img
sudo rm ./temp.img
sudo mkdir unpack/temp
sudo mv unpack/update.img unpack/temp/update.img
cd unpack
echo *.img
FILE="$( echo *.img | head -1 | tail -1 )"
DATE=`date +%Y-%m-%d_%H.%M`         
NEWFILE=${DATE}_${FILE}
mv *.img $NEWFILE        
cd ..
FILE2=final_rk3066.img      
NAME2=${FILE2%.*}
EXT2=${FILE2#*.} 
DATE2=`date +%Y-%m-%d_%H.%M`         
NEWFILE2=${DATE2}_${NAME2}.${EXT2}
sudo mv final_rk3066.img final_images/$NEWFILE2
sudo mv unpack/temp/update.img unpack/update.img
sudo rmdir unpack/temp           
}
#
function package_rom_2_3188(){
	echo "Hit -enter- key to do the final step of packaging your RK3188 rom" >$OUTPUT
    display_output 6 60 "packaging your RK3188 rom..."
cd unpack
BIN2="$( echo *.bin | head -1 | tail -1 )"
cd ..
./tools/img_maker_rk3188 ./unpack/"$BIN2" ./temp.img ./final_rk3188.img
sudo rm ./temp.img
sudo mkdir unpack/temp
sudo mv unpack/update.img unpack/temp/update.img
cd unpack
echo *.img
FILE="$( echo *.img | head -1 | tail -1 )"
DATE=`date +%Y-%m-%d_%H.%M`         
NEWFILE=${DATE}_${FILE}
mv *.img $NEWFILE        
cd ..
FILE2=final_rk3188.img           
NAME2=${FILE2%.*}
EXT2=${FILE2#*.} 
DATE2=`date +%Y-%m-%d_%H.%M`         
NEWFILE2=${DATE2}_${NAME2}.${EXT2}
sudo mv final_rk3188.img final_images/$NEWFILE2
sudo mv unpack/temp/update.img unpack/update.img
sudo rmdir unpack/temp           
}
#
function clean_unpack_dir(){
	echo "Hit -enter- key to clean all the working files from the "unpack" directory" >$OUTPUT
    display_output 6 60 "cleaning..."
rm unpack/update.img
mv unpack/*.img unpack/original_image/
mv unpack/rkunpack unpack/original_image/rkunpack
rm unpack/*
rm unpack/backupimage/*
rm unpack/Image/*
rmdir unpack/backupimage
rmdir unpack/Image
mv unpack/original_image/rkunpack unpack/rkunpack
}
#
# set infinite loop
#
while true
do
 
### display main menu ###
dialog --clear  --help-button --backtitle "RK3XXX Image Modding Tool" \
--title "[ R K 3 X X X  M O D D I N G  T O O L  F O R  U B U N T U x64 ]" \
--menu "You can use the UP/DOWN arrow keys to choose an option" 21 160 21 \
Unpack "Unpacks an RK3XXX Update Image" \
Mount_System "Mounts system.img for modding" \
Move_Apps "move all the apps we are sure we want into a "keep" directory inside of "app" directory (makes cleaning up easier)" \
Open_root_file_explorer "Opens Nautilus as root user" \
Add_Apps "Will add: Flashplayer, ESFileExplorer, googlemusic, Gallery/with online albums support, so library for eng kboard, latinime (eng keyboard), eng dictionary, asus weather widget, news widget" \
Restore_Apps "move all the apps in the "app/keep" directory back into the "app" directory." \
Build.Prop_Mod "Write TNT/Samsung SIII/English values to build.prop (backs up build.prop first)" \
Change_Boot_Animation "Change to clean google nexus "X" boot animation" \
Change_Keyboard_Sounds "Change keyboard keypress sounds to nicer CM based sounds" \
Clean_Desktop "This will clean a stock rom of the default desktop application shortcuts. You want this if you removed a bunch of chinese apps" \
Root "This will root your rom" \
Unmount_system "unmount the system.img" \
Initial_Package_Rom "This is the first packaging of your rom into a temp.img file, not ready for flashing..." \
Final_Package_RK3066 "This is the final packaging step, ONLY FOR RK3066 ROMS" \
Final_Package_RK3188 "This is the final packaging step, ONLY FOR RK3188 ROMS" \
Clean_Unpack_Dir "clean all the working files from the "unpack" directory" \
Exit "Exit to the shell" 2>"${INPUT}"

menuitem=$(<"${INPUT}")
 
 
# make decsion 
case $menuitem in
	Unpack) unpack_img;;
	Mount_System) mount_system;;
	Move_Apps) mv_apps_keep;;
	Open_root_file_explorer) open_root_file_explorer;;
	Add_Apps) add_apps;;
	Restore_Apps) mv_apps_back;;
	Build.Prop_Mod) tnt_prop_mod;;
	Change_Boot_Animation) boot_animation;;
	Change_Keyboard_Sounds) input_sounds;;
	Clean_Desktop) clean_desktop;;
	Root) root;;
	Unmount_system) unmount_system;;
	Initial_Package_Rom) package_rom_1;;
	Final_Package_RK3066) package_rom_2_3066;;
	Final_Package_RK3188) package_rom_2_3188;;
	Clean_Unpack_Dir) clean_unpack_dir;;	
	Exit) echo "Bye"; break;;
esac
 
done
 
# if temp files found, delete em
[ -f $OUTPUT ] && rm $OUTPUT
[ -f $INPUT ] && rm $INPUT
